==> haskell-doctemplates-0.11-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.11
visibility:           public
id:                   doctemplates-0.11-Fhxb714ZK1zmCs3plIEub
key:                  doctemplates-0.11-Fhxb714ZK1zmCs3plIEub
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  9a5cc06733e3dd2fd8f77b193088249b
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11-Fhxb714ZK1zmCs3plIEub
depends:
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j base-4.16.4.0
    containers-0.6.5.1 doclayout-0.4.0.1-CFs2Hx2ZHTL3OIftmkEiGR
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.15.0
    safe-0.3.21-CqIHKdkgiB2klcxc5dxay
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR text-1.2.5.0
    text-conversions-0.3.1.1-F5TZdU3eRwd6gpeVxDr0Ly
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.11-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.11
visibility:           public
id:                   doctemplates-0.11-1tHpWh7lgDpHKjHZ0nPj4S
key:                  doctemplates-0.11-1tHpWh7lgDpHKjHZ0nPj4S
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  a905ed53b5e3fba533c202d8333f8302
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctemplates-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.11-1tHpWh7lgDpHKjHZ0nPj4S
depends:
    aeson-2.1.2.1-3hy4hA3togDsVnwRqQAZI base-4.16.4.0
    containers-0.6.5.1 doclayout-0.4.0.1-CFs2Hx2ZHTL3OIftmkEiGR
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.15.0
    safe-0.3.21-CqIHKdkgiB2klcxc5dxay
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR text-1.2.5.0
    text-conversions-0.3.1.1-F5TZdU3eRwd6gpeVxDr0Ly
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
